@@ -1,4 +1,5 @@
-from whatap.trace import UdpSession, PacketTypeEnum
+from whatap.net.packet_type_enum import PacketTypeEnum
+from whatap.net.udp_session import UdpSession
 from whatap.trace.mod.application_wsgi import trace_handler
 from whatap.util.date_util import DateUtil
 from whatap.trace.trace_context_manager import TraceContextManager
@@ -18,7 +19,7 @@ def instrument_sqlalchemy(module):
             
             datas = [' ', ' ', 'DB SESSION INFO: ' + text]
             ctx.elapsed = DateUtil.nowSystem() - start_time
-            UdpSession.send_packet(PacketTypeEnum.PACKET_MSG, ctx, datas)
+            UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
             
             callback = fn(*args, **kwargs)
             return callback
