@@ -1,5 +1,5 @@
 from whatap.trace.mod.application_wsgi import transfer, trace_handler, \
-    interceptor_httpc_request
+    interceptor_httpc_request, interceptor_sock_connect
 
 
 def instrument_httplib(module):
@@ -17,7 +17,7 @@ def instrument_httplib(module):
         return trace
     
     module.HTTPConnection.request = wrapper(module.HTTPConnection.request)
-
+    module.HTTPConnection.connect = wrapper(interceptor_sock_connect)
 
 def instrument_httplib2(module):
     def wrapper(fn):
@@ -34,3 +34,5 @@ def instrument_httplib2(module):
         return trace
     
     module.Http.request = wrapper(module.Http.request)
+    module.HTTPConnectionWithTimeout.connect = wrapper(interceptor_sock_connect)
+    module.HTTPSConnectionWithTimeout.connect = wrapper(interceptor_sock_connect)
\ No newline at end of file
