@@ -1,17 +1,22 @@
 import os
 import random
 import threading
-
+import time
+import uuid
+import random
 from whatap import logging
 from whatap.conf.configure import Configure as conf
 from whatap.io.data_inputx import DataInputX
 from whatap.io.data_outputx import DataOutputX
 from whatap.util.linked_map import LinkedMap
+import whatap.util.date_util as date_util
 
 
 class TraceContextManager(object):
     entry = LinkedMap()
     local = threading.local()
+    node = uuid.getnode()
+    clock_seq = random.randrange(1 << 14)
     
     @classmethod
     def keys(cls):
@@ -36,7 +41,28 @@ class TraceContextManager(object):
             logging.debug(e, extra={'id': 'WA310'}, exc_info=True)
         
         return act
-    
+
+    @classmethod
+    def getActiveStats(cls):
+        act = [0 for _ in range(5)]
+        try:
+            en = cls.entry.values()
+            while en.hasMoreElements():
+                ctx = en.nextElement()
+                if ctx.active_sqlhash:
+                    act[1] += 1 # sql
+                elif ctx.active_httpc_hash:
+                    act[2] += 1 # httpc
+                elif ctx.db_opening:
+                    act[3] += 1 # dbc
+                elif ctx.socket_connecting:
+                    act[4] += 1  # socket
+                else:
+                    act[0] += 1 # method
+        except Exception as e:
+            logging.debug(e, extra={'id': 'WA311'}, exc_info=True)
+        return act
+
     @classmethod
     def getContextEnumeration(cls):
         return cls.entry.values()
@@ -54,11 +80,8 @@ class TraceContextManager(object):
     
     @classmethod
     def getId(cls):
-        dout = DataOutputX()
-        dout.writeFloat(random.random() * random.choice([-1, 1]))
-        dout.writeFloat(random.random())
-        din = DataInputX(dout.buffer.getvalue())
-        key = din.readLong()
+        uuid1 = uuid.uuid1(TraceContextManager.node, TraceContextManager.clock_seq)
+        key = (uuid1.int >> 64 & 0xffffffffffffffff) ^ (uuid1.int << 64 & 0xffffffffffffffff)
         return key
     
     @classmethod
@@ -71,6 +94,7 @@ class TraceContextManager(object):
         key = din.readLong() + thread_id
         cls.local.context = o
         cls.entry.put(key, o)
+
         return key
     
     @classmethod
@@ -87,7 +111,7 @@ class TraceContextManager(object):
     def end(cls, key):
         cls.local.context = None
         cls.entry.remove(key)
-    
+
     @classmethod
     def getTxProfile(cls, n):
         ctx = cls.getLocalContext()
