@@ -74,5 +74,13 @@ DEFINITION = {
         ('celery.app.trace', 'instrument_celery_execute_trace'),
         #('billiard.pool', 'instrument_billiard_pool'),
     ],
-
+    'database_redis':[
+        ('redis','instrument_redis_connection'),
+    ],
+    'email_smtp':[
+        ('smtplib','instrument_smtp'),
+    ],
+    'amqp_kombu':[
+        ('kombu','instrument_kombu'),
+    ],
 }
